print.bayprior_power_prior: Print method for bayprior_power_prior objects

View source: R/robust_priors.R

print.bayprior_power_priorR Documentation

Print method for bayprior_power_prior objects

Description

Print method for bayprior_power_prior objects

Usage

## S3 method for class 'bayprior_power_prior'
print(x, ...)

Arguments

x

A bayprior_power_prior object.

...

Ignored.

Value

Invisibly returns the input bayprior_power_prior object. Called for its side effect of printing a formatted summary of the power prior calibration, including the calibration method, target Bayes Factor, optimal delta weight, and the mean and SD of the resulting power prior.


bayprior documentation built on Aug. 27, 2026, 1:09 a.m.