View source: R/robust_priors.R
| print.bayprior_power_prior | R Documentation |
Print method for bayprior_power_prior objects
## S3 method for class 'bayprior_power_prior'
print(x, ...)
x |
A |
... |
Ignored. |
Invisibly returns the input bayprior_power_prior object.
Called for its side effect of printing a formatted summary of the power
prior calibration, including the calibration method, target Bayes Factor,
optimal delta weight, and the mean and SD of the resulting power prior.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.